@@ -48,7 +48,8 @@ galah_group_by <- function(..., expand = TRUE){
 
 parse_group_by <- function(dots){
   if(length(dots) > 0){
-    provided_variables <- dequote(unlist(lapply(dots, as_label)))
+    provided_variables <- dequote(unlist(lapply(dots, 
+                                                function(a){deparse(quo_squash(a))})))
     if (getOption("galah_config")$package$run_checks){
       validate_fields(provided_variables)
     }
